@@ -5,12 +5,113 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
     time.format = "GMT", is.ws = NULL, is.wd = NULL, is.site = NULL, 
     misc.info = NULL, bad.24 = FALSE, correct.time = NULL, output = "final") 
 {
+
+    ################################
+    #multi-format data importer
+    ################################
+    #kr version 0.lost.count
+    #21/10/2010
+    ###############################
+    #
+
+    ##############################
+    #recent changes
+    ##############################
+    #brought forward file and name import
+    ##no longer impossible
+    #
+
+    ##################
+    #to do 
+    ##################
+    #remark properly
+    #
+
+    ##################
+    #suggestions
+    ##################
+    #error catcher on read in
+    #
+
+    ###################
+    #main body
+    ###################
+
+    ##################
+    #file type
+    ##################    
+
     if (file.type == "txt") {
         sep <- "\t"
     }
     else {
         sep <- ","
     }
+
+    ##################
+    #file data read in
+    ##################
+    file.data <- read.table(file, header = FALSE, sep = sep, 
+        skip = (data.at - 1), nrows = -1, na.strings = na.strings, 
+        quote = quote, fill = TRUE)
+    if (!is.null(eof.report)) {
+        if (is.na(match(eof.report, as.character(file.data$V1))) == 
+            FALSE) {
+            file.data <- file.data[1:(match(eof.report, as.character(file.data$V1)) - 
+                1), ]
+        }
+    }
+
+    #################
+    #file names read in
+    #################
+    file.names <- if(is.null(header.at) || header.at < 1)  paste("...XxX", 1:ncol(file.data), sep="") else
+        read.table(file, header = FALSE, sep = sep, 
+            quote = quote, skip = (header.at - 1), nrows = 1, colClasses = "character")
+    file.names <- as.character(file.names)
+
+    ###############
+    #handle numerics and header=NULL
+    ##############
+
+    #if header not set
+    #need numeric or null for field sources
+    if(is.null(header.at) || is.numeric(header.at) && header.at < 1){
+        temp <- unlist(lapply(c("date.name", "time.name", "is.ws", "is.wd", "is.site"), 
+            function(x) if(!is.null(get(x)) & !is.numeric(get(x))) x))
+        if(!is.null(temp))
+            stop("Invalid import options for data import without header,\n", 
+                 "       [reset header or use numeric data field/column identifiers]\n", 
+                 "       [current conflicts: ", paste(temp, collapse = ", "), "]", 
+                 call. = FALSE)
+    }
+
+    #handle numeric field sources
+    temp <- function(x) 
+        if(is.numeric(x)) { 
+        x <- file.names[subset(x <- as.integer(x), x > 0 & x <= length(file.names))]
+        x <- if(length(x) < 1) NULL else x 
+    } else x
+
+    date.name <- temp(date.name)
+    time.name <- temp(time.name)
+    is.ws <- temp(is.ws)
+    is.wd <- temp(is.wd)
+    is.site <- temp(is.site)
+
+    temp <- c(unique(c(date.name, time.name)), is.ws, is.wd, is.site)
+    temp <- temp[duplicated(temp)]
+    temp <- unlist(lapply(c("date.name", "time.name", "is.ws", "is.wd", "is.site"), 
+               function(x) if(any(get(x) %in% temp)) x))
+    if(!is.null(temp))
+        stop("Invalid import option combination,\n", 
+             "       [conflicting options: ", 
+             paste(temp, collapse = ", "), "]", 
+            call. = FALSE)
+
+    ###################
+    #check date and time names
+    ###################
     date.name <- make.names(date.name[date.name != ""])
     time.name <- make.names(time.name[time.name != ""])
     time.name <- time.name[!time.name %in% date.name]
@@ -18,6 +119,10 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
         stop("No valid date or times set\n       [openair import currently require at least one]", 
             call. = FALSE)
     }
+
+    ####################
+    #misc.info read in
+    ####################
     if (!is.null(misc.info[1])) {
         if (is.numeric(misc.info)) {
             file.misc <- readLines(file, n = max(misc.info))
@@ -27,9 +132,10 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
             file.misc <- misc.info
         }
     }
-    file.names <- read.table(file, header = FALSE, sep = sep, 
-        quote = quote, skip = (header.at - 1), nrows = 1, colClasses = "character")
-    file.names <- as.character(file.names)
+
+    ####################
+    #date/time check
+    ###################
     if (any(!c(date.name, time.name) %in% file.names)) {
         missing.date.name <- date.name[(!date.name %in% file.names)]
         missing.time.name <- time.name[(!time.name %in% file.names)]
@@ -56,6 +162,10 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
             sep = "")
         stop(reply, call. = FALSE)
     }
+
+    ######################
+    #other field setup
+    ######################
     if (!is.null(is.ws)) {
         file.names <- gsub(is.ws, "ws", file.names, ignore.case = FALSE)
     }
@@ -65,17 +175,10 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
     if (!is.null(is.site)) {
         file.names <- gsub(is.site, "site", file.names, ignore.case = FALSE)
     }
-    file.data <- read.table(file, header = FALSE, sep = sep, 
-        skip = (data.at - 1), nrows = -1, na.strings = na.strings, 
-        quote = quote, fill = TRUE)
-    if (!is.null(eof.report)) {
-        if (is.na(match(eof.report, as.character(file.data$V1))) == 
-            FALSE) {
-            file.data <- file.data[1:(match(eof.report, as.character(file.data$V1)) - 
-                1), ]
-        }
-    }
-    #name and data dimension mismatch
+
+    #########################
+    #check name and data dimensions match
+    #########################
     if(ncol(file.data)!=length(file.names)){
         if(ncol(file.data)<length(file.names)) {
             file.names <- file.names[1:ncol(file.data)]
@@ -88,11 +191,19 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
 
         }     
     }
+
+    ######################
+    #bind data and names
+    ######################
     temp <- make.names(file.names, unique = TRUE)
     if(!identical(file.names,temp))
-        warning("Non-unqiue or non-R names extracted, names modifications applied\n       [check openair import settings and data structure if unexpected]"
+        warning("Non-unique or non-R names extracted, names modifications applied\n       [check openair import settings and data structure if unexpected]"
                 , call. = FALSE) 
     names(file.data) <- temp
+
+    #####################
+    #date/time setup
+    #####################
     if(tolower(substr(date.order,1,5))=="posix") {  
         date.order <- gsub("posix", "", date.order, ignore.case = TRUE)
         date.order <- gsub("(^ +)|( +$)", "", date.order)
@@ -121,6 +232,7 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
         time.order <- substr(time.order, 1, (nchar(time.order) - 
             1))
     }
+
     if (length(date.name) > 0) {
         if (length(date.name) == 1) {
             a <- as.character(file.data[, date.name])
@@ -132,6 +244,7 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
     else {
         a <- NULL
     }
+
     if (length(time.name) > 0) {
         if (length(time.name) == 1) {
             b <- as.character(file.data[, time.name])
@@ -143,6 +256,7 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
     else {
         b <- NULL
     }
+
     b <- apply(cbind(a, b), 1, paste, collapse = " ")
     a <- as.POSIXct(b, format = paste(date.order, time.order, 
         sep = " "), time.format)
@@ -185,9 +299,20 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
                 correct.time, " seconds)", sep = ""))
         }
     }
+
     file.data <- file.data[!names(file.data) %in% c(date.name, 
         time.name)]
+
+    ###############
+    #tidy fields are editoring
+    ###############
+    names(file.data) <- gsub("[.][.][.]XxX", "x", names(file.data))
+    file.names <- gsub("[.][.][.]XxX", "x", file.names)
     file.names2 <- file.names[!file.names %in% c(date.name, time.name)]
+
+    ###################
+    #outputs
+    ###################
     if (!output == "working") {
         if (!is.null(misc.info)) {
             comment(file.data) <- file.misc
@@ -214,6 +339,7 @@ import.2 <- function (file = file.choose(), file.type = "csv", header.at = 1,
         }
         return(ans)
     }
+
 }
 
 
