@@ -409,7 +409,7 @@ one more label than date")
 ##' Friday) and \dQuote{weekend} for convenience.
 ##' @param hour An hour or hours to select from 0-23 e.g. \code{hour = 0:12} to
 ##'   select hours 0 to 12 inclusive.
-##' @importFrom lubridate dst year month hour force_tz
+##' @importFrom lubridate dst year month hour force_tz day
 ##' @export
 ##' @author David Carslaw
 ##' @keywords methods
@@ -763,8 +763,8 @@ fitGam <- function (thedata, x = "date", y = "conc", form = y ~ x, k = k,
         }
       
       # convert class back to orginal
-      class(results$x) <- class_x
-        results
+      class(results[[x]]) <- class_x
+        return(results)
     }, error = function(x) {data.orig})
 }
 
